Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DaprControlPlaneLister ¶
type DaprControlPlaneLister interface {
// List lists all DaprControlPlanes in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.DaprControlPlane, err error)
// DaprControlPlanes returns an object that can list and get DaprControlPlanes.
DaprControlPlanes(namespace string) DaprControlPlaneNamespaceLister
DaprControlPlaneListerExpansion
}
DaprControlPlaneLister helps list DaprControlPlanes. All objects returned here must be treated as read-only.
func NewDaprControlPlaneLister ¶
func NewDaprControlPlaneLister(indexer cache.Indexer) DaprControlPlaneLister
NewDaprControlPlaneLister returns a new DaprControlPlaneLister.
type DaprControlPlaneListerExpansion ¶
type DaprControlPlaneListerExpansion interface{}
DaprControlPlaneListerExpansion allows custom methods to be added to DaprControlPlaneLister.
type DaprControlPlaneNamespaceLister ¶
type DaprControlPlaneNamespaceLister interface {
// List lists all DaprControlPlanes in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.DaprControlPlane, err error)
// Get retrieves the DaprControlPlane from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.DaprControlPlane, error)
DaprControlPlaneNamespaceListerExpansion
}
DaprControlPlaneNamespaceLister helps list and get DaprControlPlanes. All objects returned here must be treated as read-only.
type DaprControlPlaneNamespaceListerExpansion ¶
type DaprControlPlaneNamespaceListerExpansion interface{}
DaprControlPlaneNamespaceListerExpansion allows custom methods to be added to DaprControlPlaneNamespaceLister.
Click to show internal directories.
Click to hide internal directories.